@@ -51,13 +51,13 @@
 #include <KCalUtils/Stringify>
 
 #include <KMessageBox>
-#include <KSystemTimeZones>
 #include <KSharedConfig>
 
 #include <QCloseEvent>
 #include <QDir>
 #include <QIcon>
 #include <QStandardPaths>
+#include <QTimeZone>
 
 using namespace IncidenceEditorNG;
 
@@ -77,17 +77,17 @@ class IncidenceDialogPrivate : public ItemEditorUi
     Q_DECLARE_PUBLIC(IncidenceDialog)
 
 public:
-    Ui::EventOrTodoDesktop *mUi;
-    Akonadi::CollectionComboBox *mCalSelector;
-    bool mCloseOnSave;
+    Ui::EventOrTodoDesktop *mUi = nullptr;
+    Akonadi::CollectionComboBox *mCalSelector = nullptr;
+    bool mCloseOnSave = false;
 
-    EditorItemManager *mItemManager;
-    CombinedIncidenceEditor *mEditor;
-    IncidenceDateTime *mIeDateTime;
-    IncidenceAttendee *mIeAttendee;
-    IncidenceRecurrence *mIeRecurrence;
-    IncidenceResource *mIeResource;
-    bool mInitiallyDirty;
+    EditorItemManager *mItemManager = nullptr;
+    CombinedIncidenceEditor *mEditor = nullptr;
+    IncidenceDateTime *mIeDateTime = nullptr;
+    IncidenceAttendee *mIeAttendee = nullptr;
+    IncidenceRecurrence *mIeRecurrence = nullptr;
+    IncidenceResource *mIeResource = nullptr;
+    bool mInitiallyDirty = false;
     Akonadi::Item mItem;
     QString typeToString(const int type) const;
 
@@ -124,8 +124,7 @@ public:
 };
 }
 
-IncidenceDialogPrivate::IncidenceDialogPrivate(Akonadi::IncidenceChanger *changer,
-                                               IncidenceDialog *qq)
+IncidenceDialogPrivate::IncidenceDialogPrivate(Akonadi::IncidenceChanger *changer, IncidenceDialog *qq)
     : q_ptr(qq)
     , mUi(new Ui::EventOrTodoDesktop)
     , mCalSelector(new Akonadi::CollectionComboBox)
@@ -293,7 +292,7 @@ void IncidenceDialogPrivate::loadTemplate(const QString &templateName)
 {
     Q_Q(IncidenceDialog);
 
-    KCalCore::MemoryCalendar::Ptr cal(new KCalCore::MemoryCalendar(KSystemTimeZones::local()));
+    KCalCore::MemoryCalendar::Ptr cal(new KCalCore::MemoryCalendar(QTimeZone::systemTimeZone()));
 
     const QString fileName = QStandardPaths::locate(
         QStandardPaths::GenericDataLocation,
@@ -359,7 +358,7 @@ void IncidenceDialogPrivate::saveTemplate(const QString &templateName)
 {
     Q_ASSERT(!templateName.isEmpty());
 
-    KCalCore::MemoryCalendar::Ptr cal(new KCalCore::MemoryCalendar(KSystemTimeZones::local()));
+    KCalCore::MemoryCalendar::Ptr cal(new KCalCore::MemoryCalendar(QTimeZone::systemTimeZone()));
 
     switch (mEditor->type()) {
     case KCalCore::Incidence::TypeEvent:
@@ -469,7 +468,6 @@ void IncidenceDialogPrivate::updateResourceCount(int newCount)
 
 void IncidenceDialogPrivate::updateButtonStatus(bool isDirty)
 {
-    Q_Q(IncidenceDialog);
     mUi->buttonBox->button(QDialogButtonBox::Apply)->setEnabled(isDirty || mInitiallyDirty);
 }
 
@@ -479,8 +477,7 @@ bool IncidenceDialogPrivate::containsPayloadIdentifiers(
     return partIdentifiers.contains(QByteArray("PLD:RFC822"));
 }
 
-void IncidenceDialogPrivate::handleItemSaveFail(EditorItemManager::SaveAction,
-                                                const QString &errorMessage)
+void IncidenceDialogPrivate::handleItemSaveFail(EditorItemManager::SaveAction, const QString &errorMessage)
 {
     Q_Q(IncidenceDialog);
 
@@ -678,8 +675,7 @@ void IncidenceDialogPrivate::reject(RejectReason reason, const QString &errorMes
 
 /// IncidenceDialog
 
-IncidenceDialog::IncidenceDialog(Akonadi::IncidenceChanger *changer, QWidget *parent,
-                                 Qt::WindowFlags flags)
+IncidenceDialog::IncidenceDialog(Akonadi::IncidenceChanger *changer, QWidget *parent, Qt::WindowFlags flags)
     : QDialog(parent, flags)
     , d_ptr(new IncidenceDialogPrivate(changer, this))
 {
